# Summary

processing working time on backlog.

## Requirements

- Python 3.7+
- pybacklog
- pip install python-dateutil

## Install package

https://pypi.org/project/backlogprocessing/

```
pip install backlogprocessing
```

## Usage

```
from backlogprocessingmodule import *

backlogapiprocessing.run(ConfigFilePath, LoggingConfigFilePath)
```
